==> thunder_cli-2.1.2.tar.gz: lib/files_creator/setup_theme_folder.dart <==
import '../consts/const.dart';
import '../services/create_folder_files.dart';

class SetupConfigFolder {
  void setUpConfigFiles() {
    // create translations folder
    _setUpTranslations();

    // set up theme folder
    _setUpTheme();

    print("Set all files in config folder successfully 🚀🚀");
  }

  void _setUpTheme() {
    // create dark_theme_colors
    CreateFolderAndFiles().createFolder("lib/config/theme");
    CreateFolderAndFiles().createFile(
      "lib/config/theme/dark_theme_colors.dart",
      ConstStrings.instance.darkTheme,
    );

    // create light_theme_colors
    CreateFolderAndFiles().createFile(
      "lib/config/theme/light_theme_colors.dart",
      ConstStrings.instance.lightTheme,
    );

    // create my_fonts
    CreateFolderAndFiles().createFile(
      "lib/config/theme/my_fonts.dart",
      ConstStrings.instance.myFonts,
    );

    // create myStyle
    CreateFolderAndFiles().createFile(
      "lib/config/theme/my_styles.dart",
      ConstStrings.instance.myStyle,
    );

    // create myTheme
    CreateFolderAndFiles().createFile(
      "lib/config/theme/my_theme.dart",
      ConstStrings.instance.myTheme,
    );
  }

  void _setUpTranslations() {
    CreateFolderAndFiles().createFolder("lib/config/translations");

    // create localization_service
    CreateFolderAndFiles().createFile(
      "lib/config/translations/localization_service.dart",
      ConstStrings.instance.localizationService,
    );

    // create strings file
    CreateFolderAndFiles().createFile(
      "lib/config/translations/strings.dart",
      ConstStrings.instance.strings,
    );

    // create en_us_translation
    CreateFolderAndFiles().createFile(
      "lib/config/translations/ar_Ar_translation.dart",
      ConstStrings.instance.arAr,
    );

    // create ar_ar_translation
    CreateFolderAndFiles().createFile(
      "lib/config/translations/ar_En_translation.dart",
      ConstStrings.instance.enUs,
    );
  }
}

==> thunder_cli-2.1.4.tar.gz: lib/files_creator/setup_theme_folder.dart <==
import 'package:thunder_cli/consts/folder_paths.dart';

import '../consts/const.dart';
import '../services/create_folder_files.dart';

class SetupConfigFolder {
  void setUpConfigFiles() {
    // create translations folder
    _setUpTranslations();

    // set up theme folder
    _setUpTheme();

    print("Set all files in config folder successfully 🚀🚀");
  }

  void _setUpTheme() {
    // create dark_theme_colors
    CreateFolderAndFiles().createFolder(FolderPaths.themeFolder);
    CreateFolderAndFiles().createFile(
      FolderPaths.darkThemeColorsFile,
      ConstStrings.instance.darkTheme,
    );

    // create light_theme_colors
    CreateFolderAndFiles().createFile(
      FolderPaths.lightThemeColorsFile,
      ConstStrings.instance.lightTheme,
    );

    // create my_fonts
    CreateFolderAndFiles().createFile(
      FolderPaths.myFontsFile,
      ConstStrings.instance.myFonts,
    );

    // create myStyle
    CreateFolderAndFiles().createFile(
      FolderPaths.myStylesFile,
      ConstStrings.instance.myStyle,
    );

    // create myTheme
    CreateFolderAndFiles().createFile(
      FolderPaths.myThemeFile,
      ConstStrings.instance.myTheme,
    );
  }

  void _setUpTranslations() {
    CreateFolderAndFiles().createFolder(FolderPaths.translationsFolder);

    // create localization_service
    CreateFolderAndFiles().createFile(
      FolderPaths.localizationFile,
      ConstStrings.instance.localizationService,
    );

    // create strings file
    CreateFolderAndFiles().createFile(
      FolderPaths.stringsFile,
      ConstStrings.instance.strings,
    );

    // create en_us_translation
    CreateFolderAndFiles().createFile(
      FolderPaths.enFile,
      ConstStrings.instance.arAr,
    );

    // create ar_ar_translation
    CreateFolderAndFiles().createFile(
      FolderPaths.arFile,
      ConstStrings.instance.enUs,
    );
  }
}
